Module special

Module special 

Structs

Feedback
Self-referential iterator adaptor builder
FeedbackIter
Self-referential iterator adaptor

Functions

feedback
Feed the output of an iterator pipeline back to the input. Feedback is delayed by one timestep to preserve causality, so the first input is provided by initial, and the output of that pass is used as the input for the second pass, and so on.